@@ -1,4 +1,5 @@
 import yaml
+import logging
 from pyapollo.apollo_client import ApolloClient
 from typing import Any
 
@@ -13,10 +14,6 @@ class ConfigBase:
         if field in self.__annotations__:
             return self.__annotations__[field]
 
-    # def __getitem__(self, item):
-    #     if item in self.__annotations__.keys():
-    #         return self._get_config_field(item)
-
     @classmethod
     def _parse_field_type(cls, _type, value):
         func = getattr(cls, f"_parse_{_type.__name__}", cls._parse_str)
@@ -65,6 +62,7 @@ class YamlConfig(ConfigBase):
 
 class ApolloConfig(ConfigBase):
     def __init__(self, app_id: str, server_url: str, cluster: str = "default"):
+        logging.info(f"init config object [ApolloConfig], app_id: [{app_id}], server_url: [{server_url}], cluster: [{cluster}]")
         self.apollo_client = ApolloClient(
             app_id=app_id, config_server_url=server_url, cluster=cluster
         )
@@ -72,14 +70,5 @@ class ApolloConfig(ConfigBase):
     def _get_config_field(self, field: str):
         value = self.apollo_client.get_value(field)
         if value is None:
-            value = getattr(self, field)
+            return getattr(self, field)
         return self._parse_field_type(self._get_field_type(field), value)
-
-
-# class Config(ApolloConfig):
-#     ES_URI: list = None
-#     MONGO_URI: str = "mongo_uri"
-#
-#
-# config = Config("insnail-qa-robot", "http://10.0.0.176:8080", "default")
-# config.fetch()
